@@ -37,7 +37,7 @@ _dark_bg_2 = '#252515'
 class MainWindow(Tk.Frame):
 	#plt.style.use('bmh')
 	# plt.style.use('src/mode_analyzer/dark.mplstyle')
-	plt.style.use('modeanalyzer/matplotlibrc')
+	plt.style.use('matplotlibrc')
 	Z = []
 	FPthresh = []
 	FPmindist = []
